@@ -580,7 +580,7 @@ class VariableClSetup(Variable):
 
     def choice(self):
         return ["audio", "network", "locale", "video", "boot", "users",
-                "session", ""]
+                "session", "themes", ""]
 
     def humanReadable(self):
         mapType = {'network': _("network settings"),
@@ -588,6 +588,7 @@ class VariableClSetup(Variable):
                    'video': _("video settings"),
                    'boot': _("boot parameters"),
                    'audio': _("audio parameters"),
+                   'themes': _("update themes"),
                    'session': _("session settings"),
                    'users': _("user settings")}
         return mapType.get(self.Get(), "")
